#
# spec file for package spotify-qt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           spotify-qt
Version:        3.11
Release:        1.3
Summary:        Lightweight Spotify client using Qt
License:        GPL-3.0-only
URL:            https://github.com/kraxarn/spotify-qt
Source:         https://github.com/kraxarn/spotify-qt/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Group:          Productivity/Multimedia/Sound/Players
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Svg)
Suggests:       spotifyd

%description
An unofficial Spotify client using Qt as a simpler, lighter alternative to the official client, inspired by spotify-tui. Much like spotify-tui, you need an actual Spotify client running, for example spotifyd, which can be configured from within the app. Also like other clients, controlling music playback requires Spotify Premium.

%prep
%setup -q

%build
%cmake
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%license license
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/icons/hicolor/scalable/
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Mon Jan  1 2024 Jens K. <karatekhd@opensuse.org>
- Update to version 3.11
  Fixes
  * Fixed build on FreeBSD.
  * Fixed current track sometimes not showing as playing in tracks list.
  * Fixed progress slider performing double click actions with some styles.
  * Fixed HTML tags in playlists descriptions not displaying properly.
  * Fixed some systems not being able to open links or files properly.
  * Fixed "Added" sometimes showing negative values on just added tracks.
  Changes
  * Much improved performance when loading playlists.
  * Added support for track queue.
  * Added an option to ignore unavailable tracks in playlists.
  * Added support for librespot v0.5.0.
  * Added tooltips for links for artists.
  * Much improved performance with a lot of liked tracks.
  * Added support for passing custom arguments to Spotify client.
  * Added history.
  * Improved resizing with expanded album art.
  * Added an option for tabbed library and playlists.
  * The main toolbar can now be placed at the bottom of the window.
  * Settings can now be saved, even if an invalid Spotify client path is provided.
  * The shape of the album art can now be changed.
  * Improved performance with "Recent" playlist sorting.
  * Added new tooltips for tracks, albums, and playlists.
* Sat Mar 25 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.10
  Fixes
  * Fixed not being able to change volume on some styles.
  * Fixed crash when playing library items with many tracks.
  * Fixed MPRIS support on Qt 6.
  * Fixed side panel tabs not working on some styles.
  * Fixed not showing tool-tip for added date in albums.
  * Fixed using Fusion style when saving settings with default
    selected.
  * Fixed not displaying artist names with "&" properly.
  * Fixed flat buttons having a background with built-in dark theme
  * Fixed not refreshing some cached albums correctly.
  Changes
  * Added automatic re-authentication if token expired.
  * Improved error handling when setting client path.
  * Added support for saving passwords on more Linux systems.
  * Added column for track liked status.
  * Disallowed actions are now disabled.
  * Client volume is now remembered instead of always being 100%%
  * Added options for copying name of playlist/track/album.
  * Added support for librespot v0.5.0.
  * Added back lyrics.
  * Improved startup performance.
  * Replaced "Save password in keyring" option with "Remember me"
    in password entry.
  * Replaced "fixed width remaining time" with custom fixed-width
    system font.
* Thu Aug 11 2022 Jens K. <karatekhd@opensuse.org>
- Update to version 3.9
  - Fixes
  * Fixed not being able to move window under Wayland.
  * Fixed showing add and remove options for tracks in collaborative playlists.
  * Fixed some possible issues with selecting a device.
  * Fixed MPRIS support under KDE.
  * Fixed crash when opening links on some artists.
  - Changes
  * Much improved MPRIS support.
  * Added keyboard shortcuts.
  * Added support for playing tracks from outside the application.
  * Added support for selecting multiple tracks.
  * Added an option to use an expanded album cover.
  * Added an option to close application to the tray.
  * Improved detection of spotifyd config files.
  * Added an option to change device type.
  * Added message when queuing tracks.
  * Replaced custom font option with ability to select font from system.
  * Added an option to disable checking for updates on start.
* Tue Jan 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Clean up spec file a bit:
  + Drop empty post/postubn scriptlets
  + Remove not used requires on hicolor-icon-theme,
    shared-mime-info, and update-desktop-files.
  + Package license file.
  + Set license to GPL-3.0-only: there is no indication that
    GPL-3.0-or-later is valid.
* Mon Jan 17 2022 Jens K. <karatekhd@opensuse.org>
- Update to version 3.8:
  - Fixes
  * Fixed empty context menu when right-clicking empty spaces.
  * Fixed not updating playlist when deleting a track.
  * Fixed incorrect track order after deleting a track in a playlist.
  * Fixed paging not working with some lists.
  * Fixed not removing extra spacing when using system title bar.
  * Fixed issues with followed playlists by other users not updating properly.
  * Fixed issue when attempting to search for nothing.
  * Fixed issues resuming playback when last used device was no longer available.
  - Changes
  * Added an option to show desktop notification on track change.
  * Added support for repeating a single track.
  * Added support for podcasts.
  * New and improved volume slider.
  * Already opened artists are now re-used.
  * Added support for mirrored title bar buttons.
  * Added support for creating new playlists.
  * Added support for following, and unfollowing, playlists.
  * New status messages, replacing the status bar and desktop notifications.
  * Added a custom font for the custom dark theme.
  * Now continues playing tracks from search results.
  * Now shows more artists links, for example social media links.
  * Removed broken "PulseAudio volume control" setting.
  * Tracks in albums now show an added date for when the album released.
  * New categories in settings for logs and for troubleshooting.
* Sun Aug 15 2021 Jens K. <jens@karatek.net>
- Bump version to 3.7
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Add description.
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Stuff
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Initial Commit
